# https://fedoraproject.org/wiki/Packaging:Haskell

%global pkg_name pandoc-citeproc

# currently assumes datafile in system datadir
%bcond_with tests

Name:           %{pkg_name}
Version:        0.7.4
Release:        1%{?dist}
Summary:        Citeproc support for pandoc

License:        BSD
Url:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  chrpath
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-pretty-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hs-bibutils-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-pandoc-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rfc5051-devel
BuildRequires:  ghc-setenv-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-yaml-devel
# End cabal-rpm deps

%description
The pandoc-citeproc library exports functions for using the citeproc system
with pandoc. It relies on citeproc-hs, a library for rendering bibliographic
reference citations into a variety of styles using a macro language called
Citation Style Language (CSL). More details on CSL can be found here:
<http://citationstyles.org/>.

Currently this package includes a heavily revised copy of the citeproc-hs code.
When citeproc-hs is updated to be compatible, this package will simply depend
on citeproc-hs.

This package also contains an executable: pandoc-citeproc, which works as a
pandoc filter, and also has a mode for converting bibliographic databases a
YAML format suitable for inclusion in pandoc YAML metadata.


%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.


%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Provides:       ghc-%{name}-static = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       ghc-%{name}%{?_isa} = %{version}-%{release}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.


%prep
%setup -q


%build
%ghc_lib_build


%install
%ghc_lib_install

%ghc_fix_dynamic_rpath %{pkg_name}

rm %{buildroot}%{ghc_pkgdocdir}/LICENSE


%check
%if %{with tests}
%cabal test
%endif


%post -n ghc-%{name}-devel
%ghc_pkg_recache


%postun -n ghc-%{name}-devel
%ghc_pkg_recache


%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}-%{version}
%{_mandir}/man1/%{name}.1*


%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE


%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc README.md


%changelog
* Tue Nov 24 2015 Jens Petersen <petersen@redhat.com> - 0.7.4-1
- update to 0.7.4
  https://github.com/jgm/pandoc-citeproc/releases?after=0.7.2
- xml-conduit replaces xml

* Fri Sep 18 2015 Jens Petersen <petersen@redhat.com> - 0.5-4
- use license macro

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Mar  4 2015 Jens Petersen <petersen@fedoraproject.org> - 0.5-2
- rebuild

* Mon Jan 26 2015 Jens Petersen <petersen@redhat.com> - 0.5-1
- update to 0.5

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri May  9 2014 Jens Petersen <petersen@redhat.com> - 0.3.1-1
- update to 0.3.1
- build with -O1 to avoid exhausting memory in koji

* Thu May  1 2014 Jens Petersen <petersen@redhat.com> - 0.3.0.1-1
- use xml instead of hexpat

* Wed Jan 22 2014 Fedora Haskell SIG <haskell@lists.fedoraproject.org> - 0.3.0.1
- spec file generated by cabal-rpm-0.8.8
